@@ -1,7 +1,9 @@
-from .base_metric_loss_function import BaseMetricLossFunction
-from ..utils import loss_and_miner_utils as lmu, common_functions as c_f
 import torch
+
 from ..distances import LpDistance
+from ..utils import common_functions as c_f
+from ..utils import loss_and_miner_utils as lmu
+from .base_metric_loss_function import BaseMetricLossFunction
 
 
 class NCALoss(BaseMetricLossFunction):
@@ -13,11 +15,11 @@ class NCALoss(BaseMetricLossFunction):
         )
 
     # https://www.cs.toronto.edu/~hinton/absps/nca.pdf
-    def compute_loss(self, embeddings, labels, indices_tuple):
+    def compute_loss(self, embeddings, labels, indices_tuple, ref_emb, ref_labels):
         if len(embeddings) <= 1:
             return self.zero_losses()
         return self.nca_computation(
-            embeddings, embeddings, labels, labels, indices_tuple
+            embeddings, ref_emb, labels, ref_labels, indices_tuple
         )
 
     def nca_computation(
@@ -30,8 +32,8 @@ class NCALoss(BaseMetricLossFunction):
             mat = -mat
         if query is reference:
             mat.fill_diagonal_(c_f.neg_inf(dtype))
-        same_labels = (query_labels.unsqueeze(1) == reference_labels.unsqueeze(0)).type(
-            dtype
+        same_labels = c_f.to_dtype(
+            query_labels.unsqueeze(1) == reference_labels.unsqueeze(0), dtype=dtype
         )
         exp = torch.nn.functional.softmax(self.softmax_scale * mat, dim=1)
         exp = torch.sum(exp * same_labels, dim=1)
